@@ -1,10 +1,6 @@
-// 2015-edition macros.
-#[macro_use]
-extern crate clap;
-
 use std::io::Write;
 
-use structopt::StructOpt;
+use clap::Parser;
 
 mod args;
 mod report;
@@ -19,13 +15,14 @@ fn main() {
 
 fn run() -> proc_exit::ExitResult {
     // clap's `get_matches` uses Failure rather than Usage, so bypass it for `get_matches_safe`.
-    let args = match args::Args::from_args_safe() {
+    let args = match args::Args::try_parse() {
         Ok(args) => args,
         Err(e) if e.use_stderr() => {
-            return Err(proc_exit::Code::USAGE_ERR.with_message(e));
+            let _ = e.print();
+            return proc_exit::Code::USAGE_ERR.ok();
         }
         Err(e) => {
-            writeln!(std::io::stdout(), "{}", e)?;
+            let _ = e.print();
             return proc_exit::Code::SUCCESS.ok();
         }
     };
@@ -34,12 +31,12 @@ fn run() -> proc_exit::ExitResult {
 
     init_logging(args.verbose.log_level());
 
-    let stdout_palette = if concolor_control::get(concolor_control::Stream::Stdout).ansi_color() {
+    let stdout_palette = if concolor::get(concolor::Stream::Stdout).ansi_color() {
         report::Palette::colored()
     } else {
         report::Palette::plain()
     };
-    let stderr_palette = if concolor_control::get(concolor_control::Stream::Stderr).ansi_color() {
+    let stderr_palette = if concolor::get(concolor::Stream::Stderr).ansi_color() {
         report::Palette::colored()
     } else {
         report::Palette::plain()
@@ -269,7 +266,7 @@ fn init_logging(level: Option<log::Level>) {
     if let Some(level) = level {
         let mut builder = env_logger::Builder::new();
 
-        let colored = concolor_control::get(concolor_control::Stream::Stderr).ansi_color();
+        let colored = concolor::get(concolor::Stream::Stderr).ansi_color();
         builder.write_style(if colored {
             env_logger::WriteStyle::Always
         } else {
